# sprog

[![Build](https://github.com/jburgy/sprog/actions/workflows/pythonpackage.yml/badge.svg)](https://github.com/jburgy/sprog/actions/workflows/pythonpackage.yml)
[![license](https://img.shields.io/badge/License-MIT-purple.svg)](LICENSE)
[![docs](https://readthedocs.org/projects/sprog/badge/)](https://sprog.rtfd.io/)
[![codecov](https://codecov.io/gh/jburgy/sprog/graph/badge.svg?token=NZ8F26O8JZ)](https://codecov.io/gh/jburgy/sprog)

Sparse linear algebra for linear programming
